An acknowledger that does nothing.
If you want to use this acknowledger in messages produced by your
Broadway.Producer, you can get its configuration by calling
the init/0 function. For example, you can use it in
Broadway.test_message/3:
Broadway.test_message(MyPipeline, "some data", acknowledger: Broadway.NoopAcknowledger.init())Broadway sets this acknowledger automatically on messages that have been acked
via Broadway.Message.ack_immediately/1.
Summary
Functions
@spec init() :: Broadway.Message.acknowledger()
Returns the acknowledger metadata.